# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v3/discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/discovery/v3/discovery.proto',
  package='envoy.service.discovery.v3',
  syntax='proto3',
  serialized_options=b'\n(io.envoyproxy.envoy.service.discovery.v3B\016DiscoveryProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*envoy/service/discovery/v3/discovery.proto\x12\x1a\x65nvoy.service.discovery.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17google/rpc/status.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xe4\x01\n\x10\x44iscoveryRequest\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12(\n\x04node\x18\x02 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x16\n\x0eresource_names\x18\x03 \x03(\t\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x16\n\x0eresponse_nonce\x18\x05 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x06 \x01(\x0b\x32\x12.google.rpc.Status:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.DiscoveryRequest\"\xe5\x01\n\x11\x44iscoveryResponse\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12\'\n\tresources\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06\x63\x61nary\x18\x03 \x01(\x08\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x39\n\rcontrol_plane\x18\x06 \x01(\x0b\x32\".envoy.config.core.v3.ControlPlane:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.DiscoveryResponse\"\xb9\x03\n\x15\x44\x65ltaDiscoveryRequest\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x1a.envoy.config.core.v3.Node\x12\x10\n\x08type_url\x18\x02 \x01(\t\x12 \n\x18resource_names_subscribe\x18\x03 \x03(\t\x12\"\n\x1aresource_names_unsubscribe\x18\x04 \x03(\t\x12q\n\x19initial_resource_versions\x18\x05 \x03(\x0b\x32N.envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry\x12\x16\n\x0eresponse_nonce\x18\x06 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x07 \x01(\x0b\x32\x12.google.rpc.Status\x1a>\n\x1cInitialResourceVersionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.DeltaDiscoveryRequest\"\x91\x02\n\x16\x44\x65ltaDiscoveryResponse\x12\x1b\n\x13system_version_info\x18\x01 \x01(\t\x12\x37\n\tresources\x18\x02 \x03(\x0b\x32$.envoy.service.discovery.v3.Resource\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x19\n\x11removed_resources\x18\x06 \x03(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x39\n\rcontrol_plane\x18\x07 \x01(\x0b\x32\".envoy.config.core.v3.ControlPlane:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.DeltaDiscoveryResponse\"\x98\x02\n\x08Resource\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x61liases\x18\x04 \x03(\t\x12\x0f\n\x07version\x18\x01 \x01(\t\x12&\n\x08resource\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\x03ttl\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\rcache_control\x18\x07 \x01(\x0b\x32\x31.envoy.service.discovery.v3.Resource.CacheControl\x1a$\n\x0c\x43\x61\x63heControl\x12\x14\n\x0c\x64o_not_cache\x18\x01 \x01(\x08:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.ResourceBD\n(io.envoyproxy.envoy.service.discovery.v3B\x0e\x44iscoveryProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_DISCOVERYREQUEST = _descriptor.Descriptor(
  name='DiscoveryRequest',
  full_name='envoy.service.discovery.v3.DiscoveryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.service.discovery.v3.DiscoveryRequest.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.discovery.v3.DiscoveryRequest.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names', full_name='envoy.service.discovery.v3.DiscoveryRequest.resource_names', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DiscoveryRequest.type_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_nonce', full_name='envoy.service.discovery.v3.DiscoveryRequest.response_nonce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_detail', full_name='envoy.service.discovery.v3.DiscoveryRequest.error_detail', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.api.v2.DiscoveryRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=486,
)


_DISCOVERYRESPONSE = _descriptor.Descriptor(
  name='DiscoveryResponse',
  full_name='envoy.service.discovery.v3.DiscoveryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_info', full_name='envoy.service.discovery.v3.DiscoveryResponse.version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='envoy.service.discovery.v3.DiscoveryResponse.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canary', full_name='envoy.service.discovery.v3.DiscoveryResponse.canary', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DiscoveryResponse.type_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='envoy.service.discovery.v3.DiscoveryResponse.nonce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_plane', full_name='envoy.service.discovery.v3.DiscoveryResponse.control_plane', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.DiscoveryResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=718,
)


_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY = _descriptor.Descriptor(
  name='InitialResourceVersionsEntry',
  full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1119,
)

_DELTADISCOVERYREQUEST = _descriptor.Descriptor(
  name='DeltaDiscoveryRequest',
  full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.type_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names_subscribe', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.resource_names_subscribe', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_names_unsubscribe', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.resource_names_unsubscribe', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_resource_versions', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.initial_resource_versions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_nonce', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.response_nonce', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_detail', full_name='envoy.service.discovery.v3.DeltaDiscoveryRequest.error_detail', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.DeltaDiscoveryRequest',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=721,
  serialized_end=1162,
)


_DELTADISCOVERYRESPONSE = _descriptor.Descriptor(
  name='DeltaDiscoveryResponse',
  full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='system_version_info', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.system_version_info', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_url', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.type_url', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removed_resources', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.removed_resources', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.nonce', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_plane', full_name='envoy.service.discovery.v3.DeltaDiscoveryResponse.control_plane', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.api.v2.DeltaDiscoveryResponse',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1438,
)


_RESOURCE_CACHECONTROL = _descriptor.Descriptor(
  name='CacheControl',
  full_name='envoy.service.discovery.v3.Resource.CacheControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='do_not_cache', full_name='envoy.service.discovery.v3.Resource.CacheControl.do_not_cache', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1691,
)

_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='envoy.service.discovery.v3.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.service.discovery.v3.Resource.name', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aliases', full_name='envoy.service.discovery.v3.Resource.aliases', index=1,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='envoy.service.discovery.v3.Resource.version', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='envoy.service.discovery.v3.Resource.resource', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='envoy.service.discovery.v3.Resource.ttl', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_control', full_name='envoy.service.discovery.v3.Resource.cache_control', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCE_CACHECONTROL, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.api.v2.Resource',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1441,
  serialized_end=1721,
)

_DISCOVERYREQUEST.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_DISCOVERYREQUEST.fields_by_name['error_detail'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DISCOVERYRESPONSE.fields_by_name['resources'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_DISCOVERYRESPONSE.fields_by_name['control_plane'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._CONTROLPLANE
_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY.containing_type = _DELTADISCOVERYREQUEST
_DELTADISCOVERYREQUEST.fields_by_name['node'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._NODE
_DELTADISCOVERYREQUEST.fields_by_name['initial_resource_versions'].message_type = _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY
_DELTADISCOVERYREQUEST.fields_by_name['error_detail'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DELTADISCOVERYRESPONSE.fields_by_name['resources'].message_type = _RESOURCE
_DELTADISCOVERYRESPONSE.fields_by_name['control_plane'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._CONTROLPLANE
_RESOURCE_CACHECONTROL.containing_type = _RESOURCE
_RESOURCE.fields_by_name['resource'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_RESOURCE.fields_by_name['ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RESOURCE.fields_by_name['cache_control'].message_type = _RESOURCE_CACHECONTROL
DESCRIPTOR.message_types_by_name['DiscoveryRequest'] = _DISCOVERYREQUEST
DESCRIPTOR.message_types_by_name['DiscoveryResponse'] = _DISCOVERYRESPONSE
DESCRIPTOR.message_types_by_name['DeltaDiscoveryRequest'] = _DELTADISCOVERYREQUEST
DESCRIPTOR.message_types_by_name['DeltaDiscoveryResponse'] = _DELTADISCOVERYRESPONSE
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiscoveryRequest = _reflection.GeneratedProtocolMessageType('DiscoveryRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCOVERYREQUEST,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DiscoveryRequest)
  })
_sym_db.RegisterMessage(DiscoveryRequest)

DiscoveryResponse = _reflection.GeneratedProtocolMessageType('DiscoveryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCOVERYRESPONSE,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DiscoveryResponse)
  })
_sym_db.RegisterMessage(DiscoveryResponse)

DeltaDiscoveryRequest = _reflection.GeneratedProtocolMessageType('DeltaDiscoveryRequest', (_message.Message,), {

  'InitialResourceVersionsEntry' : _reflection.GeneratedProtocolMessageType('InitialResourceVersionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY,
    '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DeltaDiscoveryRequest.InitialResourceVersionsEntry)
    })
  ,
  'DESCRIPTOR' : _DELTADISCOVERYREQUEST,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DeltaDiscoveryRequest)
  })
_sym_db.RegisterMessage(DeltaDiscoveryRequest)
_sym_db.RegisterMessage(DeltaDiscoveryRequest.InitialResourceVersionsEntry)

DeltaDiscoveryResponse = _reflection.GeneratedProtocolMessageType('DeltaDiscoveryResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELTADISCOVERYRESPONSE,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.DeltaDiscoveryResponse)
  })
_sym_db.RegisterMessage(DeltaDiscoveryResponse)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {

  'CacheControl' : _reflection.GeneratedProtocolMessageType('CacheControl', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCE_CACHECONTROL,
    '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
    # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.Resource.CacheControl)
    })
  ,
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'envoy.service.discovery.v3.discovery_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.discovery.v3.Resource)
  })
_sym_db.RegisterMessage(Resource)
_sym_db.RegisterMessage(Resource.CacheControl)


DESCRIPTOR._options = None
_DISCOVERYREQUEST._options = None
_DISCOVERYRESPONSE._options = None
_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY._options = None
_DELTADISCOVERYREQUEST._options = None
_DELTADISCOVERYRESPONSE._options = None
_RESOURCE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/v3/http_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/v3/http_status.proto',
  package='envoy.type.v3',
  syntax='proto3',
  serialized_options=b'\n\033io.envoyproxy.envoy.type.v3B\017HttpStatusProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x65nvoy/type/v3/http_status.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"_\n\nHttpStatus\x12\x33\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.envoy.type.v3.StatusCodeB\n\xfa\x42\x07\x82\x01\x04\x10\x01 \x00:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.type.HttpStatus*\xb5\t\n\nStatusCode\x12\t\n\x05\x45mpty\x10\x00\x12\x0c\n\x08\x43ontinue\x10\x64\x12\x07\n\x02OK\x10\xc8\x01\x12\x0c\n\x07\x43reated\x10\xc9\x01\x12\r\n\x08\x41\x63\x63\x65pted\x10\xca\x01\x12 \n\x1bNonAuthoritativeInformation\x10\xcb\x01\x12\x0e\n\tNoContent\x10\xcc\x01\x12\x11\n\x0cResetContent\x10\xcd\x01\x12\x13\n\x0ePartialContent\x10\xce\x01\x12\x10\n\x0bMultiStatus\x10\xcf\x01\x12\x14\n\x0f\x41lreadyReported\x10\xd0\x01\x12\x0b\n\x06IMUsed\x10\xe2\x01\x12\x14\n\x0fMultipleChoices\x10\xac\x02\x12\x15\n\x10MovedPermanently\x10\xad\x02\x12\n\n\x05\x46ound\x10\xae\x02\x12\r\n\x08SeeOther\x10\xaf\x02\x12\x10\n\x0bNotModified\x10\xb0\x02\x12\r\n\x08UseProxy\x10\xb1\x02\x12\x16\n\x11TemporaryRedirect\x10\xb3\x02\x12\x16\n\x11PermanentRedirect\x10\xb4\x02\x12\x0f\n\nBadRequest\x10\x90\x03\x12\x11\n\x0cUnauthorized\x10\x91\x03\x12\x14\n\x0fPaymentRequired\x10\x92\x03\x12\x0e\n\tForbidden\x10\x93\x03\x12\r\n\x08NotFound\x10\x94\x03\x12\x15\n\x10MethodNotAllowed\x10\x95\x03\x12\x12\n\rNotAcceptable\x10\x96\x03\x12 \n\x1bProxyAuthenticationRequired\x10\x97\x03\x12\x13\n\x0eRequestTimeout\x10\x98\x03\x12\r\n\x08\x43onflict\x10\x99\x03\x12\t\n\x04Gone\x10\x9a\x03\x12\x13\n\x0eLengthRequired\x10\x9b\x03\x12\x17\n\x12PreconditionFailed\x10\x9c\x03\x12\x14\n\x0fPayloadTooLarge\x10\x9d\x03\x12\x0f\n\nURITooLong\x10\x9e\x03\x12\x19\n\x14UnsupportedMediaType\x10\x9f\x03\x12\x18\n\x13RangeNotSatisfiable\x10\xa0\x03\x12\x16\n\x11\x45xpectationFailed\x10\xa1\x03\x12\x17\n\x12MisdirectedRequest\x10\xa5\x03\x12\x18\n\x13UnprocessableEntity\x10\xa6\x03\x12\x0b\n\x06Locked\x10\xa7\x03\x12\x15\n\x10\x46\x61iledDependency\x10\xa8\x03\x12\x14\n\x0fUpgradeRequired\x10\xaa\x03\x12\x19\n\x14PreconditionRequired\x10\xac\x03\x12\x14\n\x0fTooManyRequests\x10\xad\x03\x12 \n\x1bRequestHeaderFieldsTooLarge\x10\xaf\x03\x12\x18\n\x13InternalServerError\x10\xf4\x03\x12\x13\n\x0eNotImplemented\x10\xf5\x03\x12\x0f\n\nBadGateway\x10\xf6\x03\x12\x17\n\x12ServiceUnavailable\x10\xf7\x03\x12\x13\n\x0eGatewayTimeout\x10\xf8\x03\x12\x1c\n\x17HTTPVersionNotSupported\x10\xf9\x03\x12\x1a\n\x15VariantAlsoNegotiates\x10\xfa\x03\x12\x18\n\x13InsufficientStorage\x10\xfb\x03\x12\x11\n\x0cLoopDetected\x10\xfc\x03\x12\x10\n\x0bNotExtended\x10\xfe\x03\x12\"\n\x1dNetworkAuthenticationRequired\x10\xff\x03\x42\x38\n\x1bio.envoyproxy.envoy.type.v3B\x0fHttpStatusProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_STATUSCODE = _descriptor.EnumDescriptor(
  name='StatusCode',
  full_name='envoy.type.v3.StatusCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Empty', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Continue', index=1, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=2, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Created', index=3, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Accepted', index=4, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NonAuthoritativeInformation', index=5, number=203,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NoContent', index=6, number=204,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ResetContent', index=7, number=205,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PartialContent', index=8, number=206,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MultiStatus', index=9, number=207,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AlreadyReported', index=10, number=208,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMUsed', index=11, number=226,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MultipleChoices', index=12, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MovedPermanently', index=13, number=301,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Found', index=14, number=302,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SeeOther', index=15, number=303,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NotModified', index=16, number=304,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UseProxy', index=17, number=305,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TemporaryRedirect', index=18, number=307,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PermanentRedirect', index=19, number=308,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BadRequest', index=20, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Unauthorized', index=21, number=401,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PaymentRequired', index=22, number=402,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Forbidden', index=23, number=403,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NotFound', index=24, number=404,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MethodNotAllowed', index=25, number=405,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NotAcceptable', index=26, number=406,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ProxyAuthenticationRequired', index=27, number=407,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RequestTimeout', index=28, number=408,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Conflict', index=29, number=409,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Gone', index=30, number=410,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LengthRequired', index=31, number=411,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PreconditionFailed', index=32, number=412,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PayloadTooLarge', index=33, number=413,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='URITooLong', index=34, number=414,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UnsupportedMediaType', index=35, number=415,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RangeNotSatisfiable', index=36, number=416,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ExpectationFailed', index=37, number=417,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MisdirectedRequest', index=38, number=421,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UnprocessableEntity', index=39, number=422,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Locked', index=40, number=423,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FailedDependency', index=41, number=424,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UpgradeRequired', index=42, number=426,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PreconditionRequired', index=43, number=428,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TooManyRequests', index=44, number=429,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RequestHeaderFieldsTooLarge', index=45, number=431,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='InternalServerError', index=46, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NotImplemented', index=47, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BadGateway', index=48, number=502,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ServiceUnavailable', index=49, number=503,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GatewayTimeout', index=50, number=504,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTTPVersionNotSupported', index=51, number=505,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VariantAlsoNegotiates', index=52, number=506,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='InsufficientStorage', index=53, number=507,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LoopDetected', index=54, number=508,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NotExtended', index=55, number=510,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NetworkAuthenticationRequired', index=56, number=511,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=239,
  serialized_end=1444,
)
_sym_db.RegisterEnumDescriptor(_STATUSCODE)

StatusCode = enum_type_wrapper.EnumTypeWrapper(_STATUSCODE)
Empty = 0
Continue = 100
OK = 200
Created = 201
Accepted = 202
NonAuthoritativeInformation = 203
NoContent = 204
ResetContent = 205
PartialContent = 206
MultiStatus = 207
AlreadyReported = 208
IMUsed = 226
MultipleChoices = 300
MovedPermanently = 301
Found = 302
SeeOther = 303
NotModified = 304
UseProxy = 305
TemporaryRedirect = 307
PermanentRedirect = 308
BadRequest = 400
Unauthorized = 401
PaymentRequired = 402
Forbidden = 403
NotFound = 404
MethodNotAllowed = 405
NotAcceptable = 406
ProxyAuthenticationRequired = 407
RequestTimeout = 408
Conflict = 409
Gone = 410
LengthRequired = 411
PreconditionFailed = 412
PayloadTooLarge = 413
URITooLong = 414
UnsupportedMediaType = 415
RangeNotSatisfiable = 416
ExpectationFailed = 417
MisdirectedRequest = 421
UnprocessableEntity = 422
Locked = 423
FailedDependency = 424
UpgradeRequired = 426
PreconditionRequired = 428
TooManyRequests = 429
RequestHeaderFieldsTooLarge = 431
InternalServerError = 500
NotImplemented = 501
BadGateway = 502
ServiceUnavailable = 503
GatewayTimeout = 504
HTTPVersionNotSupported = 505
VariantAlsoNegotiates = 506
InsufficientStorage = 507
LoopDetected = 508
NotExtended = 510
NetworkAuthenticationRequired = 511



_HTTPSTATUS = _descriptor.Descriptor(
  name='HttpStatus',
  full_name='envoy.type.v3.HttpStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='envoy.type.v3.HttpStatus.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\202\001\004\020\001 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.type.HttpStatus',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=236,
)

_HTTPSTATUS.fields_by_name['code'].enum_type = _STATUSCODE
DESCRIPTOR.message_types_by_name['HttpStatus'] = _HTTPSTATUS
DESCRIPTOR.enum_types_by_name['StatusCode'] = _STATUSCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpStatus = _reflection.GeneratedProtocolMessageType('HttpStatus', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSTATUS,
  '__module__' : 'envoy.type.v3.http_status_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.v3.HttpStatus)
  })
_sym_db.RegisterMessage(HttpStatus)


DESCRIPTOR._options = None
_HTTPSTATUS.fields_by_name['code']._options = None
_HTTPSTATUS._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/watchdog/v3alpha/abort_action.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/watchdog/v3alpha/abort_action.proto',
  package='envoy.watchdog.v3alpha',
  syntax='proto3',
  serialized_options=b'\n$io.envoyproxy.envoy.watchdog.v3alphaB\020AbortActionProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/watchdog/v3alpha/abort_action.proto\x12\x16\x65nvoy.watchdog.v3alpha\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\"E\n\x11\x41\x62ortActionConfig\x12\x30\n\rwait_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationBJ\n$io.envoyproxy.envoy.watchdog.v3alphaB\x10\x41\x62ortActionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_ABORTACTIONCONFIG = _descriptor.Descriptor(
  name='AbortActionConfig',
  full_name='envoy.watchdog.v3alpha.AbortActionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wait_duration', full_name='envoy.watchdog.v3alpha.AbortActionConfig.wait_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=201,
)

_ABORTACTIONCONFIG.fields_by_name['wait_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['AbortActionConfig'] = _ABORTACTIONCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AbortActionConfig = _reflection.GeneratedProtocolMessageType('AbortActionConfig', (_message.Message,), {
  'DESCRIPTOR' : _ABORTACTIONCONFIG,
  '__module__' : 'envoy.watchdog.v3alpha.abort_action_pb2'
  # @@protoc_insertion_point(class_scope:envoy.watchdog.v3alpha.AbortActionConfig)
  })
_sym_db.RegisterMessage(AbortActionConfig)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/common/dependency/v3/dependency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/common/dependency/v3/dependency.proto',
  package='envoy.extensions.filters.common.dependency.v3',
  syntax='proto3',
  serialized_options=b'\n;io.envoyproxy.envoy.extensions.filters.common.dependency.v3B\017DependencyProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>envoy/extensions/filters/common/dependency/v3/dependency.proto\x12-envoy.extensions.filters.common.dependency.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc5\x01\n\nDependency\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.envoy.extensions.filters.common.dependency.v3.Dependency.DependencyType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"H\n\x0e\x44\x65pendencyType\x12\n\n\x06HEADER\x10\x00\x12\x14\n\x10\x46ILTER_STATE_KEY\x10\x01\x12\x14\n\x10\x44YNAMIC_METADATA\x10\x02\"\xe4\x02\n\x12\x46ilterDependencies\x12R\n\x0f\x64\x65\x63ode_required\x18\x01 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x64\x65\x63ode_provided\x18\x02 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x65ncode_required\x18\x03 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.Dependency\x12R\n\x0f\x65ncode_provided\x18\x04 \x03(\x0b\x32\x39.envoy.extensions.filters.common.dependency.v3.DependencyBX\n;io.envoyproxy.envoy.extensions.filters.common.dependency.v3B\x0f\x44\x65pendencyProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_DEPENDENCY_DEPENDENCYTYPE = _descriptor.EnumDescriptor(
  name='DependencyType',
  full_name='envoy.extensions.filters.common.dependency.v3.Dependency.DependencyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEADER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTER_STATE_KEY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_METADATA', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=295,
  serialized_end=367,
)
_sym_db.RegisterEnumDescriptor(_DEPENDENCY_DEPENDENCYTYPE)


_DEPENDENCY = _descriptor.Descriptor(
  name='Dependency',
  full_name='envoy.extensions.filters.common.dependency.v3.Dependency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='envoy.extensions.filters.common.dependency.v3.Dependency.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.extensions.filters.common.dependency.v3.Dependency.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEPENDENCY_DEPENDENCYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=367,
)


_FILTERDEPENDENCIES = _descriptor.Descriptor(
  name='FilterDependencies',
  full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='decode_required', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.decode_required', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decode_provided', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.decode_provided', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_required', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.encode_required', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_provided', full_name='envoy.extensions.filters.common.dependency.v3.FilterDependencies.encode_provided', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=726,
)

_DEPENDENCY.fields_by_name['type'].enum_type = _DEPENDENCY_DEPENDENCYTYPE
_DEPENDENCY_DEPENDENCYTYPE.containing_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['decode_required'].message_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['decode_provided'].message_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['encode_required'].message_type = _DEPENDENCY
_FILTERDEPENDENCIES.fields_by_name['encode_provided'].message_type = _DEPENDENCY
DESCRIPTOR.message_types_by_name['Dependency'] = _DEPENDENCY
DESCRIPTOR.message_types_by_name['FilterDependencies'] = _FILTERDEPENDENCIES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Dependency = _reflection.GeneratedProtocolMessageType('Dependency', (_message.Message,), {
  'DESCRIPTOR' : _DEPENDENCY,
  '__module__' : 'envoy.extensions.filters.common.dependency.v3.dependency_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.common.dependency.v3.Dependency)
  })
_sym_db.RegisterMessage(Dependency)

FilterDependencies = _reflection.GeneratedProtocolMessageType('FilterDependencies', (_message.Message,), {
  'DESCRIPTOR' : _FILTERDEPENDENCIES,
  '__module__' : 'envoy.extensions.filters.common.dependency.v3.dependency_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.common.dependency.v3.FilterDependencies)
  })
_sym_db.RegisterMessage(FilterDependencies)


DESCRIPTOR._options = None
_DEPENDENCY.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/init_dump.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v3/init_dump.proto',
  package='envoy.admin.v3',
  syntax='proto3',
  serialized_options=b'\n\034io.envoyproxy.envoy.admin.v3B\rInitDumpProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1e\x65nvoy/admin/v3/init_dump.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1dudpa/annotations/status.proto\"\xa6\x01\n\x13UnreadyTargetsDumps\x12U\n\x15unready_targets_dumps\x18\x01 \x03(\x0b\x32\x36.envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump\x1a\x38\n\x12UnreadyTargetsDump\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0ctarget_names\x18\x02 \x03(\tB7\n\x1cio.envoyproxy.envoy.admin.v3B\rInitDumpProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP = _descriptor.Descriptor(
  name='UnreadyTargetsDump',
  full_name='envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_names', full_name='envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump.target_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=248,
)

_UNREADYTARGETSDUMPS = _descriptor.Descriptor(
  name='UnreadyTargetsDumps',
  full_name='envoy.admin.v3.UnreadyTargetsDumps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unready_targets_dumps', full_name='envoy.admin.v3.UnreadyTargetsDumps.unready_targets_dumps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=248,
)

_UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP.containing_type = _UNREADYTARGETSDUMPS
_UNREADYTARGETSDUMPS.fields_by_name['unready_targets_dumps'].message_type = _UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP
DESCRIPTOR.message_types_by_name['UnreadyTargetsDumps'] = _UNREADYTARGETSDUMPS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnreadyTargetsDumps = _reflection.GeneratedProtocolMessageType('UnreadyTargetsDumps', (_message.Message,), {

  'UnreadyTargetsDump' : _reflection.GeneratedProtocolMessageType('UnreadyTargetsDump', (_message.Message,), {
    'DESCRIPTOR' : _UNREADYTARGETSDUMPS_UNREADYTARGETSDUMP,
    '__module__' : 'envoy.admin.v3.init_dump_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v3.UnreadyTargetsDumps.UnreadyTargetsDump)
    })
  ,
  'DESCRIPTOR' : _UNREADYTARGETSDUMPS,
  '__module__' : 'envoy.admin.v3.init_dump_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.UnreadyTargetsDumps)
  })
_sym_db.RegisterMessage(UnreadyTargetsDumps)
_sym_db.RegisterMessage(UnreadyTargetsDumps.UnreadyTargetsDump)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/rbac/v4alpha/rbac.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import address_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2
from envoy.config.route.v4alpha import route_components_pb2 as envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2
from envoy.type.matcher.v4alpha import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2
from envoy.type.matcher.v4alpha import path_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2
from envoy.type.matcher.v4alpha import string_pb2 as envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2
from google.api.expr.v1alpha1 import checked_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2
from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/rbac/v4alpha/rbac.proto',
  package='envoy.config.rbac.v4alpha',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.rbac.v4alphaB\tRbacProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$envoy/config/rbac/v4alpha/rbac.proto\x12\x19\x65nvoy.config.rbac.v4alpha\x1a\'envoy/config/core/v4alpha/address.proto\x1a\x31\x65nvoy/config/route/v4alpha/route_components.proto\x1a)envoy/type/matcher/v4alpha/metadata.proto\x1a%envoy/type/matcher/v4alpha/path.proto\x1a\'envoy/type/matcher/v4alpha/string.proto\x1a&google/api/expr/v1alpha1/checked.proto\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xa7\x02\n\x04RBAC\x12@\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32&.envoy.config.rbac.v4alpha.RBAC.ActionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12?\n\x08policies\x18\x02 \x03(\x0b\x32-.envoy.config.rbac.v4alpha.RBAC.PoliciesEntry\x1aR\n\rPoliciesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.envoy.config.rbac.v4alpha.Policy:\x02\x38\x01\"&\n\x06\x41\x63tion\x12\t\n\x05\x41LLOW\x10\x00\x12\x08\n\x04\x44\x45NY\x10\x01\x12\x07\n\x03LOG\x10\x02: \x9a\xc5\x88\x1e\x1b\n\x19\x65nvoy.config.rbac.v3.RBAC\"\xc7\x02\n\x06Policy\x12\x44\n\x0bpermissions\x18\x01 \x03(\x0b\x32%.envoy.config.rbac.v4alpha.PermissionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x42\n\nprincipals\x18\x02 \x03(\x0b\x32$.envoy.config.rbac.v4alpha.PrincipalB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x33\n\tcondition\x18\x03 \x01(\x0b\x32\x1e.google.api.expr.v1alpha1.ExprH\x00\x12\x42\n\x11\x63hecked_condition\x18\x04 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExprH\x00:\"\x9a\xc5\x88\x1e\x1d\n\x1b\x65nvoy.config.rbac.v3.PolicyB\x16\n\x14\x65xpression_specifier\"\xf4\x05\n\nPermission\x12>\n\tand_rules\x18\x01 \x01(\x0b\x32).envoy.config.rbac.v4alpha.Permission.SetH\x00\x12=\n\x08or_rules\x18\x02 \x01(\x0b\x32).envoy.config.rbac.v4alpha.Permission.SetH\x00\x12\x16\n\x03\x61ny\x18\x03 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12;\n\x06header\x18\x04 \x01(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcherH\x00\x12;\n\x08url_path\x18\n \x01(\x0b\x32\'.envoy.type.matcher.v4alpha.PathMatcherH\x00\x12>\n\x0e\x64\x65stination_ip\x18\x05 \x01(\x0b\x32$.envoy.config.core.v4alpha.CidrRangeH\x00\x12%\n\x10\x64\x65stination_port\x18\x06 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12?\n\x08metadata\x18\x07 \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcherH\x00\x12\x39\n\x08not_rule\x18\x08 \x01(\x0b\x32%.envoy.config.rbac.v4alpha.PermissionH\x00\x12J\n\x15requested_server_name\x18\t \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcherH\x00\x1aq\n\x03Set\x12>\n\x05rules\x18\x01 \x03(\x0b\x32%.envoy.config.rbac.v4alpha.PermissionB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:*\x9a\xc5\x88\x1e%\n#envoy.config.rbac.v3.Permission.Set:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.config.rbac.v3.PermissionB\x0b\n\x04rule\x12\x03\xf8\x42\x01\"\xa3\x07\n\tPrincipal\x12;\n\x07\x61nd_ids\x18\x01 \x01(\x0b\x32(.envoy.config.rbac.v4alpha.Principal.SetH\x00\x12:\n\x06or_ids\x18\x02 \x01(\x0b\x32(.envoy.config.rbac.v4alpha.Principal.SetH\x00\x12\x16\n\x03\x61ny\x18\x03 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12K\n\rauthenticated\x18\x04 \x01(\x0b\x32\x32.envoy.config.rbac.v4alpha.Principal.AuthenticatedH\x00\x12@\n\x10\x64irect_remote_ip\x18\n \x01(\x0b\x32$.envoy.config.core.v4alpha.CidrRangeH\x00\x12\x39\n\tremote_ip\x18\x0b \x01(\x0b\x32$.envoy.config.core.v4alpha.CidrRangeH\x00\x12;\n\x06header\x18\x06 \x01(\x0b\x32).envoy.config.route.v4alpha.HeaderMatcherH\x00\x12;\n\x08url_path\x18\t \x01(\x0b\x32\'.envoy.type.matcher.v4alpha.PathMatcherH\x00\x12?\n\x08metadata\x18\x07 \x01(\x0b\x32+.envoy.type.matcher.v4alpha.MetadataMatcherH\x00\x12\x36\n\x06not_id\x18\x08 \x01(\x0b\x32$.envoy.config.rbac.v4alpha.PrincipalH\x00\x1am\n\x03Set\x12;\n\x03ids\x18\x01 \x03(\x0b\x32$.envoy.config.rbac.v4alpha.PrincipalB\x08\xfa\x42\x05\x92\x01\x02\x08\x01:)\x9a\xc5\x88\x1e$\n\"envoy.config.rbac.v3.Principal.Set\x1a\x8d\x01\n\rAuthenticated\x12\x41\n\x0eprincipal_name\x18\x02 \x01(\x0b\x32).envoy.type.matcher.v4alpha.StringMatcher:3\x9a\xc5\x88\x1e.\n,envoy.config.rbac.v3.Principal.AuthenticatedJ\x04\x08\x01\x10\x02:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.config.rbac.v3.PrincipalB\x11\n\nidentifier\x12\x03\xf8\x42\x01J\x04\x08\x05\x10\x06R\tsource_ipB>\n\'io.envoyproxy.envoy.config.rbac.v4alphaB\tRbacProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2.DESCRIPTOR,envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2.DESCRIPTOR,google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2.DESCRIPTOR,google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_RBAC_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='envoy.config.rbac.v4alpha.RBAC.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ALLOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DENY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=676,
  serialized_end=714,
)
_sym_db.RegisterEnumDescriptor(_RBAC_ACTION)


_RBAC_POLICIESENTRY = _descriptor.Descriptor(
  name='PoliciesEntry',
  full_name='envoy.config.rbac.v4alpha.RBAC.PoliciesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.rbac.v4alpha.RBAC.PoliciesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.rbac.v4alpha.RBAC.PoliciesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=592,
  serialized_end=674,
)

_RBAC = _descriptor.Descriptor(
  name='RBAC',
  full_name='envoy.config.rbac.v4alpha.RBAC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='envoy.config.rbac.v4alpha.RBAC.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policies', full_name='envoy.config.rbac.v4alpha.RBAC.policies', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RBAC_POLICIESENTRY, ],
  enum_types=[
    _RBAC_ACTION,
  ],
  serialized_options=b'\232\305\210\036\033\n\031envoy.config.rbac.v3.RBAC',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=748,
)


_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='envoy.config.rbac.v4alpha.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='envoy.config.rbac.v4alpha.Policy.permissions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='principals', full_name='envoy.config.rbac.v4alpha.Policy.principals', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='envoy.config.rbac.v4alpha.Policy.condition', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checked_condition', full_name='envoy.config.rbac.v4alpha.Policy.checked_condition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\035\n\033envoy.config.rbac.v3.Policy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expression_specifier', full_name='envoy.config.rbac.v4alpha.Policy.expression_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=751,
  serialized_end=1078,
)


_PERMISSION_SET = _descriptor.Descriptor(
  name='Set',
  full_name='envoy.config.rbac.v4alpha.Permission.Set',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.rbac.v4alpha.Permission.Set.rules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036%\n#envoy.config.rbac.v3.Permission.Set',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1671,
  serialized_end=1784,
)

_PERMISSION = _descriptor.Descriptor(
  name='Permission',
  full_name='envoy.config.rbac.v4alpha.Permission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='and_rules', full_name='envoy.config.rbac.v4alpha.Permission.and_rules', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='or_rules', full_name='envoy.config.rbac.v4alpha.Permission.or_rules', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any', full_name='envoy.config.rbac.v4alpha.Permission.any', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.config.rbac.v4alpha.Permission.header', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url_path', full_name='envoy.config.rbac.v4alpha.Permission.url_path', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_ip', full_name='envoy.config.rbac.v4alpha.Permission.destination_ip', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_port', full_name='envoy.config.rbac.v4alpha.Permission.destination_port', index=6,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\377\377\003', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.rbac.v4alpha.Permission.metadata', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_rule', full_name='envoy.config.rbac.v4alpha.Permission.not_rule', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_server_name', full_name='envoy.config.rbac.v4alpha.Permission.requested_server_name', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PERMISSION_SET, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.config.rbac.v3.Permission',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rule', full_name='envoy.config.rbac.v4alpha.Permission.rule',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1081,
  serialized_end=1837,
)


_PRINCIPAL_SET = _descriptor.Descriptor(
  name='Set',
  full_name='envoy.config.rbac.v4alpha.Principal.Set',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='envoy.config.rbac.v4alpha.Principal.Set.ids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.rbac.v3.Principal.Set',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2443,
  serialized_end=2552,
)

_PRINCIPAL_AUTHENTICATED = _descriptor.Descriptor(
  name='Authenticated',
  full_name='envoy.config.rbac.v4alpha.Principal.Authenticated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='principal_name', full_name='envoy.config.rbac.v4alpha.Principal.Authenticated.principal_name', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.config.rbac.v3.Principal.Authenticated',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2555,
  serialized_end=2696,
)

_PRINCIPAL = _descriptor.Descriptor(
  name='Principal',
  full_name='envoy.config.rbac.v4alpha.Principal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='and_ids', full_name='envoy.config.rbac.v4alpha.Principal.and_ids', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='or_ids', full_name='envoy.config.rbac.v4alpha.Principal.or_ids', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='any', full_name='envoy.config.rbac.v4alpha.Principal.any', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authenticated', full_name='envoy.config.rbac.v4alpha.Principal.authenticated', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_remote_ip', full_name='envoy.config.rbac.v4alpha.Principal.direct_remote_ip', index=4,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_ip', full_name='envoy.config.rbac.v4alpha.Principal.remote_ip', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='envoy.config.rbac.v4alpha.Principal.header', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url_path', full_name='envoy.config.rbac.v4alpha.Principal.url_path', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='envoy.config.rbac.v4alpha.Principal.metadata', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_id', full_name='envoy.config.rbac.v4alpha.Principal.not_id', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PRINCIPAL_SET, _PRINCIPAL_AUTHENTICATED, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.config.rbac.v3.Principal',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identifier', full_name='envoy.config.rbac.v4alpha.Principal.identifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1840,
  serialized_end=2771,
)

_RBAC_POLICIESENTRY.fields_by_name['value'].message_type = _POLICY
_RBAC_POLICIESENTRY.containing_type = _RBAC
_RBAC.fields_by_name['action'].enum_type = _RBAC_ACTION
_RBAC.fields_by_name['policies'].message_type = _RBAC_POLICIESENTRY
_RBAC_ACTION.containing_type = _RBAC
_POLICY.fields_by_name['permissions'].message_type = _PERMISSION
_POLICY.fields_by_name['principals'].message_type = _PRINCIPAL
_POLICY.fields_by_name['condition'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._EXPR
_POLICY.fields_by_name['checked_condition'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2._CHECKEDEXPR
_POLICY.oneofs_by_name['expression_specifier'].fields.append(
  _POLICY.fields_by_name['condition'])
_POLICY.fields_by_name['condition'].containing_oneof = _POLICY.oneofs_by_name['expression_specifier']
_POLICY.oneofs_by_name['expression_specifier'].fields.append(
  _POLICY.fields_by_name['checked_condition'])
_POLICY.fields_by_name['checked_condition'].containing_oneof = _POLICY.oneofs_by_name['expression_specifier']
_PERMISSION_SET.fields_by_name['rules'].message_type = _PERMISSION
_PERMISSION_SET.containing_type = _PERMISSION
_PERMISSION.fields_by_name['and_rules'].message_type = _PERMISSION_SET
_PERMISSION.fields_by_name['or_rules'].message_type = _PERMISSION_SET
_PERMISSION.fields_by_name['header'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_PERMISSION.fields_by_name['url_path'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2._PATHMATCHER
_PERMISSION.fields_by_name['destination_ip'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._CIDRRANGE
_PERMISSION.fields_by_name['metadata'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
_PERMISSION.fields_by_name['not_rule'].message_type = _PERMISSION
_PERMISSION.fields_by_name['requested_server_name'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['and_rules'])
_PERMISSION.fields_by_name['and_rules'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['or_rules'])
_PERMISSION.fields_by_name['or_rules'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['any'])
_PERMISSION.fields_by_name['any'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['header'])
_PERMISSION.fields_by_name['header'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['url_path'])
_PERMISSION.fields_by_name['url_path'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['destination_ip'])
_PERMISSION.fields_by_name['destination_ip'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['destination_port'])
_PERMISSION.fields_by_name['destination_port'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['metadata'])
_PERMISSION.fields_by_name['metadata'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['not_rule'])
_PERMISSION.fields_by_name['not_rule'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PERMISSION.oneofs_by_name['rule'].fields.append(
  _PERMISSION.fields_by_name['requested_server_name'])
_PERMISSION.fields_by_name['requested_server_name'].containing_oneof = _PERMISSION.oneofs_by_name['rule']
_PRINCIPAL_SET.fields_by_name['ids'].message_type = _PRINCIPAL
_PRINCIPAL_SET.containing_type = _PRINCIPAL
_PRINCIPAL_AUTHENTICATED.fields_by_name['principal_name'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_string__pb2._STRINGMATCHER
_PRINCIPAL_AUTHENTICATED.containing_type = _PRINCIPAL
_PRINCIPAL.fields_by_name['and_ids'].message_type = _PRINCIPAL_SET
_PRINCIPAL.fields_by_name['or_ids'].message_type = _PRINCIPAL_SET
_PRINCIPAL.fields_by_name['authenticated'].message_type = _PRINCIPAL_AUTHENTICATED
_PRINCIPAL.fields_by_name['direct_remote_ip'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._CIDRRANGE
_PRINCIPAL.fields_by_name['remote_ip'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_address__pb2._CIDRRANGE
_PRINCIPAL.fields_by_name['header'].message_type = envoy_dot_config_dot_route_dot_v4alpha_dot_route__components__pb2._HEADERMATCHER
_PRINCIPAL.fields_by_name['url_path'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_path__pb2._PATHMATCHER
_PRINCIPAL.fields_by_name['metadata'].message_type = envoy_dot_type_dot_matcher_dot_v4alpha_dot_metadata__pb2._METADATAMATCHER
_PRINCIPAL.fields_by_name['not_id'].message_type = _PRINCIPAL
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['and_ids'])
_PRINCIPAL.fields_by_name['and_ids'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['or_ids'])
_PRINCIPAL.fields_by_name['or_ids'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['any'])
_PRINCIPAL.fields_by_name['any'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['authenticated'])
_PRINCIPAL.fields_by_name['authenticated'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['direct_remote_ip'])
_PRINCIPAL.fields_by_name['direct_remote_ip'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['remote_ip'])
_PRINCIPAL.fields_by_name['remote_ip'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['header'])
_PRINCIPAL.fields_by_name['header'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['url_path'])
_PRINCIPAL.fields_by_name['url_path'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['metadata'])
_PRINCIPAL.fields_by_name['metadata'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
_PRINCIPAL.oneofs_by_name['identifier'].fields.append(
  _PRINCIPAL.fields_by_name['not_id'])
_PRINCIPAL.fields_by_name['not_id'].containing_oneof = _PRINCIPAL.oneofs_by_name['identifier']
DESCRIPTOR.message_types_by_name['RBAC'] = _RBAC
DESCRIPTOR.message_types_by_name['Policy'] = _POLICY
DESCRIPTOR.message_types_by_name['Permission'] = _PERMISSION
DESCRIPTOR.message_types_by_name['Principal'] = _PRINCIPAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RBAC = _reflection.GeneratedProtocolMessageType('RBAC', (_message.Message,), {

  'PoliciesEntry' : _reflection.GeneratedProtocolMessageType('PoliciesEntry', (_message.Message,), {
    'DESCRIPTOR' : _RBAC_POLICIESENTRY,
    '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.RBAC.PoliciesEntry)
    })
  ,
  'DESCRIPTOR' : _RBAC,
  '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.RBAC)
  })
_sym_db.RegisterMessage(RBAC)
_sym_db.RegisterMessage(RBAC.PoliciesEntry)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {
  'DESCRIPTOR' : _POLICY,
  '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.Policy)
  })
_sym_db.RegisterMessage(Policy)

Permission = _reflection.GeneratedProtocolMessageType('Permission', (_message.Message,), {

  'Set' : _reflection.GeneratedProtocolMessageType('Set', (_message.Message,), {
    'DESCRIPTOR' : _PERMISSION_SET,
    '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.Permission.Set)
    })
  ,
  'DESCRIPTOR' : _PERMISSION,
  '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.Permission)
  })
_sym_db.RegisterMessage(Permission)
_sym_db.RegisterMessage(Permission.Set)

Principal = _reflection.GeneratedProtocolMessageType('Principal', (_message.Message,), {

  'Set' : _reflection.GeneratedProtocolMessageType('Set', (_message.Message,), {
    'DESCRIPTOR' : _PRINCIPAL_SET,
    '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.Principal.Set)
    })
  ,

  'Authenticated' : _reflection.GeneratedProtocolMessageType('Authenticated', (_message.Message,), {
    'DESCRIPTOR' : _PRINCIPAL_AUTHENTICATED,
    '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.Principal.Authenticated)
    })
  ,
  'DESCRIPTOR' : _PRINCIPAL,
  '__module__' : 'envoy.config.rbac.v4alpha.rbac_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.rbac.v4alpha.Principal)
  })
_sym_db.RegisterMessage(Principal)
_sym_db.RegisterMessage(Principal.Set)
_sym_db.RegisterMessage(Principal.Authenticated)


DESCRIPTOR._options = None
_RBAC_POLICIESENTRY._options = None
_RBAC.fields_by_name['action']._options = None
_RBAC._options = None
_POLICY.fields_by_name['permissions']._options = None
_POLICY.fields_by_name['principals']._options = None
_POLICY._options = None
_PERMISSION_SET.fields_by_name['rules']._options = None
_PERMISSION_SET._options = None
_PERMISSION.oneofs_by_name['rule']._options = None
_PERMISSION.fields_by_name['any']._options = None
_PERMISSION.fields_by_name['destination_port']._options = None
_PERMISSION._options = None
_PRINCIPAL_SET.fields_by_name['ids']._options = None
_PRINCIPAL_SET._options = None
_PRINCIPAL_AUTHENTICATED._options = None
_PRINCIPAL.oneofs_by_name['identifier']._options = None
_PRINCIPAL.fields_by_name['any']._options = None
_PRINCIPAL._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/core/v3/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from xds.core.v3 import resource_name_pb2 as xds_dot_core_dot_v3_dot_resource__name__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='xds/core/v3/resource.proto',
  package='xds.core.v3',
  syntax='proto3',
  serialized_options=b'\n\033com.github.udpa.xds.core.v3B\rResourceProtoP\001\272\200\310\321\006\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1axds/core/v3/resource.proto\x12\x0bxds.core.v3\x1a\x19google/protobuf/any.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1fxds/core/v3/resource_name.proto\"l\n\x08Resource\x12\'\n\x04name\x18\x01 \x01(\x0b\x32\x19.xds.core.v3.ResourceName\x12\x0f\n\x07version\x18\x02 \x01(\t\x12&\n\x08resource\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB6\n\x1b\x63om.github.udpa.xds.core.v3B\rResourceProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,xds_dot_core_dot_v3_dot_resource__name__pb2.DESCRIPTOR,])




_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='xds.core.v3.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='xds.core.v3.Resource.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='xds.core.v3.Resource.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='xds.core.v3.Resource.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=242,
)

_RESOURCE.fields_by_name['name'].message_type = xds_dot_core_dot_v3_dot_resource__name__pb2._RESOURCENAME
_RESOURCE.fields_by_name['resource'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCE,
  '__module__' : 'xds.core.v3.resource_pb2'
  # @@protoc_insertion_point(class_scope:xds.core.v3.Resource)
  })
_sym_db.RegisterMessage(Resource)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/file/v3/file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import substitution_format_string_pb2 as envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/access_loggers/file/v3/file.proto',
  package='envoy.extensions.access_loggers.file.v3',
  syntax='proto3',
  serialized_options=b'\n5io.envoyproxy.envoy.extensions.access_loggers.file.v3B\tFileProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2envoy/extensions/access_loggers/file/v3/file.proto\x12\'envoy.extensions.access_loggers.file.v3\x1a\x35\x65nvoy/config/core/v3/substitution_format_string.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbf\x02\n\rFileAccessLog\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x14\n\x06\x66ormat\x18\x02 \x01(\tB\x02\x18\x01H\x00\x12\x32\n\x0bjson_format\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12\x38\n\x11typed_json_format\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12N\n\nlog_format\x18\x05 \x01(\x0b\x32..envoy.config.core.v3.SubstitutionFormatStringB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:.\x9a\xc5\x88\x1e)\n\'envoy.config.accesslog.v2.FileAccessLogB\x13\n\x11\x61\x63\x63\x65ss_log_formatBL\n5io.envoyproxy.envoy.extensions.access_loggers.file.v3B\tFileProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_FILEACCESSLOG = _descriptor.Descriptor(
  name='FileAccessLog',
  full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.format', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.json_format', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_json_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.typed_json_format', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.log_format', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036)\n\'envoy.config.accesslog.v2.FileAccessLog',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='access_log_format', full_name='envoy.extensions.access_loggers.file.v3.FileAccessLog.access_log_format',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=272,
  serialized_end=591,
)

_FILEACCESSLOG.fields_by_name['json_format'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FILEACCESSLOG.fields_by_name['typed_json_format'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_FILEACCESSLOG.fields_by_name['log_format'].message_type = envoy_dot_config_dot_core_dot_v3_dot_substitution__format__string__pb2._SUBSTITUTIONFORMATSTRING
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['format'])
_FILEACCESSLOG.fields_by_name['format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['json_format'])
_FILEACCESSLOG.fields_by_name['json_format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['typed_json_format'])
_FILEACCESSLOG.fields_by_name['typed_json_format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
_FILEACCESSLOG.oneofs_by_name['access_log_format'].fields.append(
  _FILEACCESSLOG.fields_by_name['log_format'])
_FILEACCESSLOG.fields_by_name['log_format'].containing_oneof = _FILEACCESSLOG.oneofs_by_name['access_log_format']
DESCRIPTOR.message_types_by_name['FileAccessLog'] = _FILEACCESSLOG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FileAccessLog = _reflection.GeneratedProtocolMessageType('FileAccessLog', (_message.Message,), {
  'DESCRIPTOR' : _FILEACCESSLOG,
  '__module__' : 'envoy.extensions.access_loggers.file.v3.file_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.access_loggers.file.v3.FileAccessLog)
  })
_sym_db.RegisterMessage(FileAccessLog)


DESCRIPTOR._options = None
_FILEACCESSLOG.fields_by_name['path']._options = None
_FILEACCESSLOG.fields_by_name['format']._options = None
_FILEACCESSLOG.fields_by_name['json_format']._options = None
_FILEACCESSLOG.fields_by_name['typed_json_format']._options = None
_FILEACCESSLOG.fields_by_name['log_format']._options = None
_FILEACCESSLOG._options = None
# @@protoc_insertion_point(module_scope)
